@@ -7,6 +7,7 @@
 #define INDEX_H
 
 #include <QObject>
+#include <QUrl>
 #include <QStringList>
 
 class Index : public QObject
@@ -21,15 +22,6 @@ signals:
     void openPath(QStringList paths);
 
 public slots:
-    bool supportsEmbededTerminal()
-    {
-#ifdef EMBEDDED_TERMINAL
-        return true;
-#else
-        return false;
-#endif
-    }
-
     static QUrl cameraPath();
     static QUrl screenshotsPath();
 
